pub enum ActEvent {
Created,
Completed,
BeforeUpdate,
Updated,
Step,
}Variants
Created
trigger when task created
Completed
trigger when task completed
BeforeUpdate
before act executing
Updated
trigger when act to update the state based on Step node
Step
trigger when step move to next based on Workflow node